@@ -27,8 +27,6 @@ Config::Config():
     remSize_ (true),
     remPos_ (false),
     remSplitterPos_ (true),
-    iconless_ (false),
-    sysIcon_ (false),
     noToolbar_ (false),
     noMenubar_ (false),
     hideSearchbar_ (false),
@@ -39,7 +37,7 @@ Config::Config():
     remFont_ (true),
     wrapByDefault_ (true),
     indentByDefault_ (true),
-    autoReplace_ (true),
+    autoReplace_ (false),
     autoBracket_ (false),
     lineByDefault_ (false),
     syntaxByDefault_ (true),
@@ -62,6 +60,7 @@ Config::Config():
     skipNonText_ (true),
     saveUnmodified_ (false),
     closeWithLastTab_ (false),
+    sharedSearchHistory_ (false),
     vLineDistance_ (-80),
     tabPosition_ (0),
     maxSHSize_ (2),
@@ -122,12 +121,6 @@ void Config::readConfig()
 
     prefSize_ = settings.value ("prefSize").toSize();
 
-    if (settings.value ("iconless").toBool())
-        iconless_ = true; // false by default
-
-    if (settings.value ("sysIcon").toBool())
-        sysIcon_ = true; // false by default
-
     if (settings.value ("noToolbar").toBool())
         noToolbar_ = true; // false by default
 
@@ -176,6 +169,9 @@ void Config::readConfig()
     if (settings.value ("closeWithLastTab").toBool())
         closeWithLastTab_ = true; // false by default
 
+    if (settings.value ("sharedSearchHistory").toBool())
+        sharedSearchHistory_ = true; // false by default
+
     settings.endGroup();
 
     /************
@@ -204,9 +200,8 @@ void Config::readConfig()
     if (settings.value ("noIndent").toBool())
         indentByDefault_ = false; // true by default
 
-    v = settings.value ("autoReplace");
-    if (v.isValid()) // true by default
-        autoReplace_ = v.toBool();
+    if (settings.value ("autoReplace").toBool())
+        autoReplace_ = true; // false by default
 
     if (settings.value ("autoBracket").toBool())
         autoBracket_ = true; // false by default
@@ -308,8 +303,9 @@ void Config::readShortcuts()
     for (int i = 0; i < actions.size(); ++i)
     {
         QVariant v = settings.value (actions.at (i));
-        QString vs = validatedShortcut (v);
-        if (!vs.isEmpty())
+        bool isValid;
+        QString vs = validatedShortcut (v, &isValid);
+        if (isValid)
             setActionShortcut (actions.at (i), vs);
         else // remove the key on writing config
             removedActions_ << actions.at (i);
@@ -370,8 +366,6 @@ void Config::writeConfig()
     settings.setValue ("prefSize", prefSize_);
 
     settings.setValue ("startSize", startSize_);
-    settings.setValue ("iconless", iconless_);
-    settings.setValue ("sysIcon", sysIcon_);
     settings.setValue ("noToolbar", noToolbar_);
     settings.setValue ("noMenubar", noMenubar_);
     settings.setValue ("hideSearchbar", hideSearchbar_);
@@ -385,6 +379,7 @@ void Config::writeConfig()
     settings.setValue ("openInWindows", openInWindows_);
     settings.setValue ("nativeDialog", nativeDialog_);
     settings.setValue ("closeWithLastTab", closeWithLastTab_);
+    settings.setValue ("sharedSearchHistory", sharedSearchHistory_);
 
     settings.endGroup();
 
@@ -515,12 +510,17 @@ void Config::addRecentFile (const QString& file)
         recentFiles_.removeLast();
 }
 /*************************/
-QString Config::validatedShortcut (const QVariant v)
+QString Config::validatedShortcut (const QVariant v, bool *isValid)
 {
     static QStringList added;
     if (v.isValid())
     {
         QString str = v.toString();
+        if (str.isEmpty())
+        { // it means the removal of a shortcut
+            *isValid = true;
+            return QString();
+        }
 
         /* NOTE: In older versions of FeatherPad, shorcuts were saved in
            the NativeText format. For the sake of backward compatibility,
@@ -535,11 +535,14 @@ QString Config::validatedShortcut (const QVariant v)
                 // prevent ambiguous shortcuts at startup as far as possible
                 && !added.contains (str))
             {
+                *isValid = true;
                 added << str;
                 return str;
             }
         }
     }
+
+    *isValid = false;
     return QString();
 }
 
