@@ -113,6 +113,7 @@ public slots:
     void statusMsgWithLineCount (const int lines);
     void showCursorPos();
     void updateWordInfo (int position = -1, int charsRemoved = 0, int charsAdded = 0);
+    void enableSaving (bool modified);
 
 private slots:
     void newTabFromRecent();
@@ -193,6 +194,7 @@ private slots:
     void toggleSidePane();
     void prefDialog();
     void checkSpelling();
+    void userDict();
     void aboutDialog();
     void helpDoc();
     void matchBrackets();
@@ -202,6 +204,7 @@ private slots:
                   bool uneditable, // This doc should be uneditable?
                   bool multiple); // Multiple files are being loaded?
     void onOpeningHugeFiles();
+    void onOpeninNonTextFiles();
     void onPermissionDenied();
     void onOpeningUneditable();
     void onOpeningNonexistent();
@@ -230,6 +233,7 @@ private:
     void setTitle (const QString& fileName, int tabIndex = -1);
     DOCSTATE savePrompt (int tabIndex, bool noToAll);
     bool saveFile (bool keepSyntax);
+    void saveAllFiles (bool showWarning);
     void closeEvent (QCloseEvent *event);
     bool closeTabs (int first, int last, bool saveFilesList = false);
     void dragEnterEvent (QDragEnterEvent *event);
@@ -273,12 +277,12 @@ private:
     int rightClicked_; // The index/row of the right-clicked tab/item.
     int loadingProcesses_; // The number of loading processes (used to prevent early closing).
     QPointer<QThread> busyThread_; // Used to wait one second for making the cursor busy.
-    ICONMODE iconMode_; // Used only internally.
     QMetaObject::Connection lambdaConnection_; // Captures a lambda connection to disconnect it later.
     SidePane *sidePane_;
     QHash<QListWidgetItem*, TabPage*> sideItems_; // For fast tab switching.
     QHash<QString, QAction*> langs_; // All programming languages (to be enforced by the user).
     QHash<QAction*, QKeySequence> defaultShortcuts_;
+    bool inactiveTabModified_; // The inactive tab is modified (e.g., when saving all files).
     // Auto-saving:
     QTimer *autoSaver_;
     QElapsedTimer autoSaverPause_;
