@@ -43,7 +43,7 @@ void handleQuitSignals (const std::vector<int>& quitSignals)
 int main (int argc, char **argv)
 {
     const QString name = "FeatherPad";
-    const QString version = "0.11.1";
+    const QString version = "0.12.1";
     const QString option = QString::fromUtf8 (argv[1]);
     if (option == "--help" || option == "-h")
     {
@@ -96,8 +96,10 @@ int main (int argc, char **argv)
     singleton.installTranslator (&qtTranslator);
 
     QTranslator FPTranslator;
-#ifdef Q_OS_HAIKU
+#if defined(Q_OS_HAIKU)
     FPTranslator.load ("featherpad_" + lang, "/translations");
+#elif defined(Q_OS_MAC)
+    FPTranslator.load ("featherpad_" + lang, singleton.applicationDirPath() + QStringLiteral ("/../Resources/translations/"));
 #else
     FPTranslator.load ("featherpad_" + lang, QStringLiteral (DATADIR) + "/featherpad/translations");
 #endif
