@@ -21,7 +21,7 @@
 #include "ui_fp.h"
 
 #include "pref.h"
-#include "ui_predDialog.h"
+#include "ui_prefDialog.h"
 #include "filedialog.h"
 
 #include <QScreen>
@@ -88,12 +88,10 @@ PrefDialog::PrefDialog (QWidget *parent)
     Delegate *del = new Delegate (ui->tableWidget);
     ui->tableWidget->setItemDelegate (del);
     ui->tableWidget->horizontalHeader()->setSectionResizeMode (QHeaderView::Stretch);
-    ui->tableWidget->horizontalHeader()->setSectionsClickable (false);
+    ui->tableWidget->horizontalHeader()->setSectionsClickable (true);
     ui->tableWidget->sortByColumn (0, Qt::AscendingOrder);
 
     Config config = static_cast<FPsingleton*>(qApp)->getConfig();
-    sysIcons_ = config.getSysIcon();
-    iconless_ = config.getIconless();
     darkBg_ = config.getDarkColScheme();
     darkColValue_ = config.getDarkBgColorValue();
     lightColValue_ = config.getLightBgColorValue();
@@ -103,6 +101,7 @@ PrefDialog::PrefDialog (QWidget *parent)
     vLineDistance_ = config.getVLineDistance();
     textTabSize_ = config.getTextTabSize();
     saveUnmodified_ = config.getSaveUnmodified();
+    sharedSearchHistory_ = config.getSharedSearchHistory();
 
     /**************
      *** Window ***
@@ -123,7 +122,7 @@ PrefDialog::PrefDialog (QWidget *parent)
         if (QWindow *win = parent->windowHandle())
         {
             if (QScreen *sc = win->screen())
-                ag = sc->availableVirtualGeometry().size();
+                ag = sc->availableGeometry().size();
         }
     }
     if (ag.isEmpty()) ag = QSize (qMax (700, config.getStartSize().width()), qMax (500, config.getStartSize().height()));
@@ -138,12 +137,6 @@ PrefDialog::PrefDialog (QWidget *parent)
     ui->winPosBox->setChecked (config.getRemPos());
     connect (ui->winPosBox, &QCheckBox::stateChanged, this, &PrefDialog::prefPos);
 
-    ui->iconBox->setChecked (!config.getSysIcon());
-    ui->iconBox->setEnabled (!config.getIconless());
-    connect (ui->iconBox, &QCheckBox::stateChanged, this, &PrefDialog::prefIcon);
-    ui->iconlessBox->setChecked (config.getIconless());
-    connect (ui->iconlessBox, &QCheckBox::stateChanged, this, &PrefDialog::prefIconless);
-
     ui->toolbarBox->setChecked (config.getNoToolbar());
     connect (ui->toolbarBox, &QCheckBox::stateChanged, this, &PrefDialog::prefToolbar);
     ui->menubarBox->setChecked (config.getNoMenubar());
@@ -152,6 +145,9 @@ PrefDialog::PrefDialog (QWidget *parent)
     ui->searchbarBox->setChecked (config.getHideSearchbar());
     connect (ui->searchbarBox, &QCheckBox::stateChanged, this, &PrefDialog::prefSearchbar);
 
+    ui->searchHistoryBox->setChecked (sharedSearchHistory_);
+    connect (ui->searchHistoryBox, &QCheckBox::stateChanged, this, &PrefDialog::prefSearchHistory);
+
     ui->statusBox->setChecked (config.getShowStatusbar());
     connect (ui->statusBox, &QCheckBox::stateChanged, this, &PrefDialog::prefStatusbar);
 
@@ -303,7 +299,7 @@ PrefDialog::PrefDialog (QWidget *parent)
     if (FPwin *win = static_cast<FPwin *>(parent_))
     {
         if (DEFAULT_SHORTCUTS.isEmpty())
-        { // NOTE: Shortcut strings hould be in the PortableText format.
+        { // NOTE: Shortcut strings should be in the PortableText format.
             const auto defaultShortcuts = win->defaultShortcuts();
             QHash<QAction*, QKeySequence>::const_iterator iter = defaultShortcuts.constBegin();
             while (iter != defaultShortcuts.constEnd())
@@ -347,7 +343,7 @@ PrefDialog::PrefDialog (QWidget *parent)
         QTableWidgetItem *item = new QTableWidgetItem (it.key());
         item->setFlags (item->flags() & ~Qt::ItemIsEditable & ~Qt::ItemIsSelectable);
         ui->tableWidget->setItem (index, 0, item);
-        /* shortcut texts should added in the NativeText format */
+        /* shortcut texts should be added in the NativeText format */
         ui->tableWidget->setItem (index, 1, new QTableWidgetItem (QKeySequence (it.value(), QKeySequence::PortableText)
                                                                   .toString (QKeySequence::NativeText)));
         ++ it;
@@ -453,9 +449,8 @@ void PrefDialog::showPrompt (const QString& str, bool temporary)
         else
             prevtMsg_ = "<b>" + str + "</b>";
     }
-    else if (sysIcons_ != config.getSysIcon()
-            || iconless_ != config.getIconless()
-            || recentNumber_ != config.getRecentFilesNumber())
+    else if (recentNumber_ != config.getRecentFilesNumber()
+             || sharedSearchHistory_ != config.getSharedSearchHistory())
     {
         ui->promptLabel->setText ("<b>" + tr ("Application restart is needed for changes to take effect.") + "</b>");
         ui->promptLabel->setStyleSheet (style);
@@ -523,36 +518,6 @@ void PrefDialog::prefPos (int checked)
         config.setRemPos (false);
 }
 /*************************/
-void PrefDialog::prefIcon (int checked)
-{
-    Config& config = static_cast<FPsingleton*>(qApp)->getConfig();
-    if (checked == Qt::Checked)
-        config.setSysIcon (false);
-    else if (checked == Qt::Unchecked)
-        config.setSysIcon (true);
-
-    showPrompt();
-}
-/*************************/
-void PrefDialog::prefIconless (int checked)
-{
-    Config& config = static_cast<FPsingleton*>(qApp)->getConfig();
-    if (checked == Qt::Checked)
-    {
-        qApp->setAttribute (Qt::AA_DontShowIconsInMenus, true);
-        config.setIconless (true);
-        ui->iconBox->setEnabled (false);
-    }
-    else if (checked == Qt::Unchecked)
-    {
-        qApp->setAttribute (Qt::AA_DontShowIconsInMenus, false);
-        config.setIconless (false);
-        ui->iconBox->setEnabled (true);
-    }
-
-    showPrompt();
-}
-/*************************/
 void PrefDialog::prefToolbar (int checked)
 {
     FPsingleton *singleton = static_cast<FPsingleton*>(qApp);
@@ -608,6 +573,17 @@ void PrefDialog::prefSearchbar (int checked)
         config.setHideSearchbar (false);
 }
 /*************************/
+void PrefDialog::prefSearchHistory (int checked)
+{
+    Config& config = static_cast<FPsingleton*>(qApp)->getConfig();
+    if (checked == Qt::Checked)
+        config.setSharedSearchHistory (true);
+    else if (checked == Qt::Unchecked)
+        config.setSharedSearchHistory (false);
+
+    showPrompt();
+}
+/*************************/
 void PrefDialog::prefStatusbar (int checked)
 {
     FPsingleton *singleton = static_cast<FPsingleton*>(qApp);
@@ -1283,30 +1259,38 @@ void PrefDialog::onShortcutChange (QTableWidgetItem *item)
         txt = keySeq.toString();
     }
 
-    if (txt.isEmpty()
-        || (config.reservedShortcuts().contains (txt)
-            /* unless its (hard-coded) default shortcut is typed */
-            && DEFAULT_SHORTCUTS.value (OBJECT_NAMES.value (desc)) != txt))
+    if (!txt.isEmpty() && config.reservedShortcuts().contains (txt)
+        /* unless its (hard-coded) default shortcut is typed */
+        && DEFAULT_SHORTCUTS.value (OBJECT_NAMES.value (desc)) != txt)
     {
-        if (txt.isEmpty())
-            showPrompt (tr ("The typed shortcut was not valid."), true);
-        else
-            showPrompt (tr ("The typed shortcut was reserved."), true);
+        showPrompt (tr ("The typed shortcut was reserved."), true);
         disconnect (ui->tableWidget, &QTableWidget::itemChanged, this, &PrefDialog::onShortcutChange);
         item->setText (shortcuts_.value (desc));
         connect (ui->tableWidget, &QTableWidget::itemChanged, this, &PrefDialog::onShortcutChange);
     }
     else
     {
-        if (!shortcuts_.keys (txt).isEmpty())
-            showPrompt (tr ("Warning: Ambiguous shortcut detected!"), false);
-        else if (ui->promptLabel->isVisible())
+        shortcuts_.insert (desc, txt);
+        newShortcuts_.insert (OBJECT_NAMES.value (desc), txt);
+
+        /* check for ambiguous shortcuts */
+        bool ambiguous = false;
+        QList<QString> val = shortcuts_.values();
+        for (int i = 0; i < val.size(); ++i)
+        {
+            if (!val.at (i).isEmpty() && val.indexOf (val.at (i), i + 1) > -1)
+            {
+                showPrompt (tr ("Warning: Ambiguous shortcut detected!"), false);
+                ambiguous = true;
+                break;
+            }
+        }
+        if (!ambiguous && ui->promptLabel->isVisible())
         {
             prevtMsg_ = QString();
             showPrompt();
         }
-        shortcuts_.insert (desc, txt);
-        newShortcuts_.insert (OBJECT_NAMES.value (desc), txt);
+
         /* also set the state of the Default button */
         QHash<QString, QString>::const_iterator it = shortcuts_.constBegin();
         while (it != shortcuts_.constEnd())
@@ -1416,9 +1400,9 @@ void PrefDialog::prefSaveUnmodified()
         {
             TextEdit *textEdit = qobject_cast< TabPage *>(win->ui->tabWidget->widget (j))->textEdit();
             if (!saveUnmodified_)
-                disconnect (textEdit->document(), &QTextDocument::modificationChanged, win->ui->actionSave, &QAction::setEnabled);
+                disconnect (textEdit->document(), &QTextDocument::modificationChanged, win, &FPwin::enableSaving);
             else
-                connect (textEdit->document(), &QTextDocument::modificationChanged, win->ui->actionSave, &QAction::setEnabled);
+                connect (textEdit->document(), &QTextDocument::modificationChanged, win, &FPwin::enableSaving);
         }
     }
 }
