@@ -50,6 +50,9 @@ public:
     bool isX11() const {
       return isX11_;
     }
+    QStandardItemModel *searchModel() const {
+        return searchModel_;
+    }
 
 public slots:
     void receiveMessage();
@@ -73,6 +76,7 @@ private:
     QStringList lastFiles_;
     bool isX11_;
     bool socketFailure_;
+    QStandardItemModel *searchModel_; // The common search history if any.
 };
 
 }
