@@ -49,7 +49,6 @@ TextEdit::TextEdit (QWidget *parent, int bgColorValue) : QPlainTextEdit (parent)
     matchedBrackets_ = false;
 
     inertialScrolling_ = false;
-    wheelEvent_ = nullptr;
     scrollTimer_ = nullptr;
 
     prog_ = "url"; // the default language
@@ -119,6 +118,7 @@ TextEdit::TextEdit (QWidget *parent, int bgColorValue) : QPlainTextEdit (parent)
             }
         }
     }
+    bgColorValue_ = bgColorValue;
 
     resizeTimerId = 0;
     updateTimerId = 0;
@@ -134,6 +134,12 @@ TextEdit::TextEdit (QWidget *parent, int bgColorValue) : QPlainTextEdit (parent)
     VScrollBar *vScrollBar = new VScrollBar;
     setVerticalScrollBar (vScrollBar);
 
+#if (QT_VERSION >= QT_VERSION_CHECK(5,14,0))
+    /* a (temporary) workaround for Qt's horizontal scrollbar bug */
+    HScrollBar *hScrollBar = new HScrollBar;
+    setHorizontalScrollBar (hScrollBar);
+#endif
+
     lineNumberArea = new LineNumberArea (this);
     lineNumberArea->setToolTip (tr ("Double click to center current line"));
     lineNumberArea->hide();
@@ -169,7 +175,9 @@ void TextEdit::setEditorFont (const QFont &f, bool setDefault)
     /* we want consistent tabs */
     QFontMetricsF metrics (f);
     QTextOption opt = document()->defaultTextOption();
-#if (QT_VERSION >= QT_VERSION_CHECK(5,10,0))
+#if (QT_VERSION >= QT_VERSION_CHECK(5,11,0))
+    opt.setTabStopDistance (metrics.horizontalAdvance (textTab_));
+#elif (QT_VERSION >= QT_VERSION_CHECK(5,10,0))
     opt.setTabStopDistance (metrics.width (textTab_));
 #else
     opt.setTabStop (metrics.width (textTab_));
@@ -277,8 +285,8 @@ void TextEdit::updateLineNumberArea (const QRect &rect, int dy)
         lineNumberArea->scroll (0, dy);
     else
     {
-        /* since the current line number is made bold and italic,
-           it should be updated also when the line is wrapped */
+        /* since the current line number is distinguished from other numbers,
+           its rectangle should be updated also when the line is wrapped */
         if (lastCurrentLine.isValid())
             lineNumberArea->update (0, lastCurrentLine.y(), lineNumberArea->width(), lastCurrentLine.height());
         QRect totalRect;
@@ -352,7 +360,11 @@ QString TextEdit::remainingSpaces (const QString& spaceTab, const QTextCursor& c
     QTextCursor tmp = cursor;
     QString txt = cursor.block().text().left (cursor.positionInBlock());
     QFontMetricsF fm = QFontMetricsF (document()->defaultFont());
+#if (QT_VERSION >= QT_VERSION_CHECK(5,11,0))
+    qreal spaceL = fm.horizontalAdvance (" ");
+#else
     qreal spaceL = fm.width (" ");
+#endif
     int n = 0, i = 0;
     while ((i = txt.indexOf("\t", i)) != -1)
     { // find tab widths in terms of spaces
@@ -360,7 +372,7 @@ QString TextEdit::remainingSpaces (const QString& spaceTab, const QTextCursor& c
         qreal x = static_cast<qreal>(cursorRect (tmp).right());
         tmp.setPosition (tmp.position() + 1);
         x = static_cast<qreal>(cursorRect (tmp).right()) - x;
-        n += qMax (qRound (x / spaceL) - 1, 0);
+        n += qMax (qRound (qAbs (x) / spaceL) - 1, 0); // x is negative for RTL
         ++i;
     }
     n += txt.count();
@@ -389,7 +401,11 @@ QTextCursor TextEdit::backTabCursor (const QTextCursor& cursor, bool twoSpace) c
 
     QString txt = blockText.left (indx);
     QFontMetricsF fm = QFontMetricsF (document()->defaultFont());
+#if (QT_VERSION >= QT_VERSION_CHECK(5,11,0))
+    qreal spaceL = fm.horizontalAdvance (" ");
+#else
     qreal spaceL = fm.width (" ");
+#endif
     int n = 0, i = 0;
     while ((i = txt.indexOf("\t", i)) != -1)
     { // find tab widths in terms of spaces
@@ -397,7 +413,7 @@ QTextCursor TextEdit::backTabCursor (const QTextCursor& cursor, bool twoSpace) c
         qreal x = static_cast<qreal>(cursorRect (tmp).right());
         tmp.setPosition (tmp.position() + 1);
         x = static_cast<qreal>(cursorRect (tmp).right()) - x;
-        n += qMax (qRound (x / spaceL) - 1, 0);
+        n += qMax (qRound (qAbs (x) / spaceL) - 1, 0);
         ++i;
     }
     n += txt.count();
@@ -415,7 +431,7 @@ QTextCursor TextEdit::backTabCursor (const QTextCursor& cursor, bool twoSpace) c
         qreal x = static_cast<qreal>(cursorRect (tmp).right());
         tmp.setPosition (txtStart - 1, QTextCursor::KeepAnchor);
         x -= static_cast<qreal>(cursorRect (tmp).right());
-        n -= qRound (x / spaceL);
+        n -= qRound (qAbs (x) / spaceL);
         if (n < 0) n = 0; // impossible without "twoSpace"
         tmp.setPosition (tmp.position() - n, QTextCursor::KeepAnchor);
     }
@@ -514,24 +530,53 @@ void TextEdit::keyPressEvent (QKeyEvent *event)
         if (autoReplace && selTxt.isEmpty())
         {
             const int p = cur.positionInBlock();
-            if (p > 2)
+            if (p > 1)
             {
+                bool replaceStr = true;
                 cur.beginEditBlock();
-                cur.movePosition (QTextCursor::PreviousCharacter, QTextCursor::KeepAnchor, 3);
-                const QString sel = cur.selectedText();
-                if (sel == " --")
-                    cur.insertText (" —");
-                else if (sel == "...")
-                {
-                    QTextCursor prevCur = cur;
-                    prevCur.setPosition (cur.position());
-                    if (p > 3)
+                if (prog_ == "url" || prog_ == "changelog"
+                    || lang_ == "url" || lang_ == "changelog")
+                { // not with programming languages
+                    cur.movePosition (QTextCursor::PreviousCharacter, QTextCursor::KeepAnchor, 2);
+                    const QString sel = cur.selectedText();
+                    replaceStr = sel.endsWith (".");
+                    if (!replaceStr)
                     {
-                        prevCur.movePosition (QTextCursor::PreviousCharacter, QTextCursor::KeepAnchor);
-                        if (prevCur.selectedText() != ".")
-                            cur.insertText ("…");
+                        if (sel == "--")
+                        {
+                            QTextCursor prevCur = cur;
+                            prevCur.setPosition (cur.position());
+                            prevCur.movePosition (QTextCursor::PreviousCharacter, QTextCursor::KeepAnchor);
+                            if (prevCur.selectedText() != "-")
+                                cur.insertText ("—");
+                        }
+                        else if (sel == "->")
+                            cur.insertText ("→");
+                        else if (sel == "<-")
+                            cur.insertText ("←");
+                        else if (sel == ">=")
+                            cur.insertText ("≥");
+                        else if (sel == "<=")
+                            cur.insertText ("≤");
+                    }
+                }
+                if (replaceStr && p > 2)
+                {
+                    cur = textCursor();
+                    cur.movePosition (QTextCursor::PreviousCharacter, QTextCursor::KeepAnchor, 3);
+                    const QString sel = cur.selectedText();
+                    if (sel == "...")
+                    {
+                        QTextCursor prevCur = cur;
+                        prevCur.setPosition (cur.position());
+                        if (p > 3)
+                        {
+                            prevCur.movePosition (QTextCursor::PreviousCharacter, QTextCursor::KeepAnchor);
+                            if (prevCur.selectedText() != ".")
+                                cur.insertText ("…");
+                        }
+                        else cur.insertText ("…");
                     }
-                    else cur.insertText ("…");
                 }
                 cur.endEditBlock();
                 cur = textCursor(); // reset the current cursor
@@ -1012,40 +1057,70 @@ void TextEdit::keyPressEvent (QKeyEvent *event)
             return;
         }
     }
-    /* because of a bug in Qt5, the non-breaking space (ZWNJ) isn't inserted with SHIFT+SPACE */
+    /* because of a bug in Qt5, the non-breaking space (ZWNJ) may not be inserted with SHIFT+SPACE */
     else if (event->key() == 0x200c)
     {
         insertPlainText (QChar (0x200C));
         event->accept();
         return;
     }
-    else if (autoReplace && event->key() == Qt::Key_Space)
+    else if (event->key() == Qt::Key_Space)
     {
-        if (event->modifiers() == Qt::NoModifier)
+        if (autoReplace && event->modifiers() == Qt::NoModifier)
         {
             QTextCursor cur = textCursor();
             if (!cur.hasSelection())
             {
                 const int p = cur.positionInBlock();
-                if (p > 2)
+                if (p > 1)
                 {
+                    bool replaceStr = true;
                     cur.beginEditBlock();
-                    cur.movePosition (QTextCursor::PreviousCharacter, QTextCursor::KeepAnchor, 3);
-                    QString selTxt = cur.selectedText();
-                    if (selTxt == " --")
-                        cur.insertText (" —");
-                    else if (selTxt == "...")
-                    {
-                        QTextCursor prevCur = cur;
-                        prevCur.setPosition (cur.position());
-                        if (p > 3)
+                    if (prog_ == "url" || prog_ == "changelog"
+                        || lang_ == "url" || lang_ == "changelog")
+                    { // not with programming languages
+                        cur.movePosition (QTextCursor::PreviousCharacter, QTextCursor::KeepAnchor, 2);
+                        const QString selTxt = cur.selectedText();
+                        replaceStr = selTxt.endsWith (".");
+                        if (!replaceStr)
                         {
-                            prevCur.movePosition (QTextCursor::PreviousCharacter, QTextCursor::KeepAnchor);
-                            if (prevCur.selectedText() != ".")
-                                cur.insertText ("…");
+                            if (selTxt == "--")
+                            {
+                                QTextCursor prevCur = cur;
+                                prevCur.setPosition (cur.position());
+                                prevCur.movePosition (QTextCursor::PreviousCharacter, QTextCursor::KeepAnchor);
+                                if (prevCur.selectedText() != "-")
+                                    cur.insertText ("—");
+                            }
+                            else if (selTxt == "->")
+                                cur.insertText ("→");
+                            else if (selTxt == "<-")
+                                cur.insertText ("←");
+                            else if (selTxt == ">=")
+                                cur.insertText ("≥");
+                            else if (selTxt == "<=")
+                                cur.insertText ("≤");
                         }
-                        else cur.insertText ("…");
                     }
+                    if (replaceStr && p > 2)
+                    {
+                        cur = textCursor();
+                        cur.movePosition (QTextCursor::PreviousCharacter, QTextCursor::KeepAnchor, 3);
+                        const QString selTxt = cur.selectedText();
+                        if (selTxt == "...")
+                        {
+                            QTextCursor prevCur = cur;
+                            prevCur.setPosition (cur.position());
+                            if (p > 3)
+                            {
+                                prevCur.movePosition (QTextCursor::PreviousCharacter, QTextCursor::KeepAnchor);
+                                if (prevCur.selectedText() != ".")
+                                    cur.insertText ("…");
+                            }
+                            else cur.insertText ("…");
+                        }
+                    }
+
                     cur.endEditBlock();
                 }
             }
@@ -1093,62 +1168,94 @@ void TextEdit::wheelEvent (QWheelEvent *event)
             zooming (delta);
             return;
         }
+
+#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
+            bool horizontal (event->angleDelta().x() != 0);
+#else
+            bool horizontal (event->orientation() == Qt::Horizontal);
+#endif
         if (event->modifiers() & Qt::ShiftModifier)
         { // line-by-line scrolling when Shift is pressed
-            QWheelEvent e (event->pos(), event->globalPos(),
-                           event->angleDelta().y() / QApplication::wheelScrollLines(),
-                           event->buttons(), Qt::NoModifier, Qt::Vertical);
-            QCoreApplication::sendEvent (verticalScrollBar(), &e);
-            return;
-        }
-        if (!inertialScrolling_
-            || !event->spontaneous()
-            || (event->modifiers() & Qt::AltModifier))
-        { // proceed as in QPlainTextEdit::wheelEvent()
-            QAbstractScrollArea::wheelEvent (event);
-            updateMicroFocus();
+            int delta = horizontal
+                            ? event->angleDelta().x() : event->angleDelta().y();
+#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
+            QWheelEvent e (event->posF(),
+                           event->globalPosF(),
+                           event->pixelDelta(),
+#if (QT_VERSION >= QT_VERSION_CHECK(5,14,0))
+                           horizontal
+                               ? QPoint (delta / QApplication::wheelScrollLines(), 0)
+                               : QPoint (0, delta / QApplication::wheelScrollLines()),
+#else
+                           QPoint (0, delta / QApplication::wheelScrollLines()),
+#endif
+                           event->buttons(),
+                           Qt::NoModifier,
+                           event->phase(),
+                           false,
+                           event->source());
+#else
+            QWheelEvent e (event->posF(),
+                           event->globalPosF(),
+                           delta / QApplication::wheelScrollLines(),
+                           event->buttons(),
+                           Qt::NoModifier,
+                           Qt::Vertical);
+#endif
+            QCoreApplication::sendEvent (horizontal
+                                             ? horizontalScrollBar()
+                                             : verticalScrollBar(), &e);
             return;
         }
 
         /* inertial scrolling */
-        if (QScrollBar* vbar = verticalScrollBar())
+        if (inertialScrolling_
+            && event->spontaneous()
+            && !horizontal
+            && event->source() == Qt::MouseEventNotSynthesized)
         {
-            /* always set the initial speed to 3 lines per wheel turn */
-            int delta = event->angleDelta().y() * 3 / QApplication::wheelScrollLines();
-            if((delta > 0 && vbar->value() == vbar->minimum())
-               || (delta < 0 && vbar->value() == vbar->maximum()))
+            if (QScrollBar* vbar = verticalScrollBar())
             {
-                return; // the scrollbar can't move
-            }
-            /* keep track of the wheel event */
-            wheelEvent_ = event;
-            /* find the number of wheel events in 500 ms
-               and set the scroll frames per second accordingly */
-            static QList<qint64> wheelEvents;
-            wheelEvents << QDateTime::currentMSecsSinceEpoch();
-            while (wheelEvents.last() - wheelEvents.first() > 500)
-                wheelEvents.removeFirst();
-            int fps = qMax (SCROLL_FRAMES_PER_SEC / wheelEvents.size(), 5);
+                /* always set the initial speed to 3 lines per wheel turn */
+                int delta = event->angleDelta().y() * 3 / QApplication::wheelScrollLines();
+                if((delta > 0 && vbar->value() == vbar->minimum())
+                   || (delta < 0 && vbar->value() == vbar->maximum()))
+                {
+                    return; // the scrollbar can't move
+                }
+                /* find the number of wheel events in 500 ms
+                   and set the scroll frames per second accordingly */
+                static QList<qint64> wheelEvents;
+                wheelEvents << QDateTime::currentMSecsSinceEpoch();
+                while (wheelEvents.last() - wheelEvents.first() > 500)
+                    wheelEvents.removeFirst();
+                int fps = qMax (SCROLL_FRAMES_PER_SEC / wheelEvents.size(), 5);
 
-            /* set the data for inertial scrolling */
-            scrollData data;
-            data.delta = delta;
-            data.totalSteps = data.leftSteps = fps * SCROLL_DURATION / 1000;
-            queuedScrollSteps_.append (data);
-            if (!scrollTimer_)
-            {
-                scrollTimer_ = new QTimer();
-                scrollTimer_->setTimerType (Qt::PreciseTimer);
-                connect (scrollTimer_, &QTimer::timeout, this, &TextEdit::scrollWithInertia);
+                /* set the data for inertial scrolling */
+                scrollData data;
+                data.delta = delta;
+                data.totalSteps = data.leftSteps = fps * SCROLL_DURATION / 1000;
+                queuedScrollSteps_.append (data);
+                if (!scrollTimer_)
+                {
+                    scrollTimer_ = new QTimer();
+                    scrollTimer_->setTimerType (Qt::PreciseTimer);
+                    connect (scrollTimer_, &QTimer::timeout, this, &TextEdit::scrollWithInertia);
+                }
+                scrollTimer_->start (1000 / SCROLL_FRAMES_PER_SEC);
+                return;
             }
-            scrollTimer_->start (1000 / SCROLL_FRAMES_PER_SEC);
         }
+
+        /* proceed as in QPlainTextEdit::wheelEvent() */
+        QAbstractScrollArea::wheelEvent (event);
+        updateMicroFocus();
     }
 }
 /*************************/
 void TextEdit::scrollWithInertia()
 {
-    if (!wheelEvent_ || !verticalScrollBar()) return;
+    if (!verticalScrollBar()) return;
 
     int totalDelta = 0;
     for (QList<scrollData>::iterator it = queuedScrollSteps_.begin(); it != queuedScrollSteps_.end(); ++it)
@@ -1169,10 +1276,24 @@ void TextEdit::scrollWithInertia()
         }
         else break;
     }
-    /* -> qevent.cpp -> QWheelEvent::QWheelEvent() */
-    QWheelEvent e (wheelEvent_->pos(), wheelEvent_->globalPos(),
+
+#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
+    QWheelEvent e (QPointF(),
+                   QPointF(),
+                   QPoint(),
+                   QPoint (0, totalDelta),
+                   Qt::NoButton,
+                   Qt::NoModifier,
+                   Qt::NoScrollPhase,
+                   false);
+#else
+    QWheelEvent e (QPointF(),
+                   QPointF(),
                    totalDelta,
-                   wheelEvent_->buttons(), Qt::NoModifier, Qt::Vertical);
+                   Qt::NoButton,
+                   Qt::NoModifier,
+                   Qt::Vertical);
+#endif
     QCoreApplication::sendEvent (verticalScrollBar(), &e);
 
     /* update text selection if the left mouse button is pressed (-> QPlainTextEdit::timerEvent) */
@@ -1249,6 +1370,29 @@ static void fillBackground (QPainter *p, const QRectF &rect, QBrush brush, const
     p->fillRect (rect, brush);
     p->restore();
 }
+
+#if (QT_VERSION >= QT_VERSION_CHECK(5,14,0))
+// To work around a nasty bug in Qt 5.14.0
+static QColor overlayColor (const QColor& bgCol, const QColor& overlayCol)
+{
+    if (!overlayCol.isValid()) return QColor(0,0,0);
+    if (!bgCol.isValid()) return overlayCol;
+
+    qreal a1 = overlayCol.alphaF();
+    if (a1 == 1.0) return overlayCol;
+    qreal a0  = bgCol.alphaF();
+    qreal a = (1.0 - a1) * a0 + a1;
+
+    QColor res;
+    res.setAlphaF(a);
+    res.setRedF (((1.0 - a1) * a0 * bgCol.redF() + a1 * overlayCol.redF()) / a);
+    res.setGreenF (((1.0 - a1) * a0 *bgCol.greenF() + a1 * overlayCol.greenF()) / a);
+    res.setBlueF (((1.0 - a1) * a0 * bgCol.blueF() + a1 * overlayCol.blueF()) / a);
+
+    return res;
+}
+#endif
+
 // Exactly like QPlainTextEdit::paintEvent(),
 // except for setting layout text option for RTL
 // and drawing vertical indentation lines (if needed).
@@ -1399,13 +1543,16 @@ void TextEdit::paintEvent (QPaintEvent *event)
                     if (darkValue > -1)
                     {
                         col = Qt::white;
-                        col.setAlpha (100);
+                        col.setAlpha (90);
                     }
                     else
                     {
                         col = Qt::black;
-                        col.setAlpha (80);
+                        col.setAlpha (70);
                     }
+#if (QT_VERSION >= QT_VERSION_CHECK(5,14,0))
+                    col = overlayColor (QColor (bgColorValue_, bgColorValue_, bgColorValue_), col);
+#endif
                     painter.setPen (col);
                 }
                 layout->draw (&painter, offset, selections, er);
@@ -1440,7 +1587,11 @@ void TextEdit::paintEvent (QPaintEvent *event)
                     int yBottom =  qRound (r.height() >= static_cast<qreal>(2) * fm.lineSpacing()
                                                ? yTop + fm.height()
                                                : r.bottomLeft().y() - static_cast<qreal>(1));
+#if (QT_VERSION >= QT_VERSION_CHECK(5,11,0))
+                    qreal tabWidth = fm.horizontalAdvance (textTab_);
+#else
                     qreal tabWidth = fm.width (textTab_);
+#endif
                     if (rtl)
                     {
                         qreal leftMost = cursorRect (cur).left();
@@ -1485,7 +1636,11 @@ void TextEdit::paintEvent (QPaintEvent *event)
                 QTextCursor cur = textCursor();
                 cur.setPosition (block.position());
                 QFontMetricsF fm = QFontMetricsF (document()->defaultFont());
+#if (QT_VERSION >= QT_VERSION_CHECK(5,11,0))
+                qreal rulerSpace = fm.horizontalAdvance (' ') * static_cast<qreal>(vLineDistance_);
+#else
                 qreal rulerSpace = fm.width (' ') * static_cast<qreal>(vLineDistance_);
+#endif
                 int yTop = qRound (r.topLeft().y());
                 int yBottom =  qRound (r.height() >= static_cast<qreal>(2) * fm.lineSpacing()
                                        ? yTop + fm.height()
@@ -1581,24 +1736,22 @@ void TextEdit::lineNumberAreaPaintEvent (QPaintEvent *event)
 
                 painter.save();
                 int cur = cursorRect().center().y();
-                int i = 0;
-                while (top + i * h < cur)
-                    ++i;
-                if (i > 0) // always the case
+                painter.setFont (bf);
+                painter.setPen (currentLineFg);
+                painter.fillRect (0, cur - h / 2, w, h, currentLineBg);
+                QTextCursor tmp = textCursor();
+                tmp.movePosition (QTextCursor::StartOfLine, QTextCursor::MoveAnchor);
+                if (!tmp.atBlockStart())
                 {
-                    painter.setFont (bf);
-                    painter.setPen (currentLineFg);
-                    painter.fillRect (0, top + (i - 1) * h, w, h, currentLineBg);
-                    if (i > 1)
+                    painter.drawText (left, cur - h / 2, w - 3, h,
+                                      Qt::AlignRight, rtl ? "↲" : "↳");
+                    painter.setPen (currentBlockFg);
+                    if (tmp.movePosition (QTextCursor::Up, QTextCursor::MoveAnchor) // always true
+                        && !tmp.atBlockStart())
                     {
-                        painter.drawText (left, top + (i - 1) * h, w - 3, h,
-                                          Qt::AlignRight, rtl ? "↲" : "↳");
-                        painter.setPen (currentBlockFg);
-                        if (i > 2)
-                        {
-                            painter.drawText (left, top + (i - 2) * h, w - 3, h,
-                                              Qt::AlignRight, number);
-                        }
+                        cur = cursorRect (tmp).center().y();
+                        painter.drawText (left, cur - h / 2, w - 3, h,
+                                          Qt::AlignRight, number);
                     }
                 }
             }
@@ -1741,9 +1894,9 @@ void TextEdit::sortLines (bool reverse)
     cursor.endEditBlock();
 }
 
-/*****************************************************
-***** The following functions are for hyperlinks *****
-******************************************************/
+/************************************************************
+***** The following functions are mainly for hyperlinks *****
+*************************************************************/
 
 QString TextEdit::getUrl (const int pos) const
 {
@@ -1752,7 +1905,7 @@ QString TextEdit::getUrl (const int pos) const
     QString url;
     QTextBlock block = document()->findBlock (pos);
     QString text = block.text();
-    if (text.length() <= 50000) // otherwise, too long
+    if (text.length() <= 10000) // otherwise, too long
     {
         int cursorIndex = pos - block.position();
         QRegularExpressionMatch match;
@@ -1790,6 +1943,43 @@ void TextEdit::mouseMoveEvent (QMouseEvent *event)
 /*************************/
 void TextEdit::mousePressEvent (QMouseEvent *event)
 {
+    /* With a triple click, QPlainTextEdit selects the current block
+       plus its newline, if any. But it is better to select the
+       current block without selecting its newline and start and end
+       whitespaces (because, for example, the selection clipboard might
+       be pasted into a terminal emulator). */
+    if (tripleClickTimer_.isValid())
+    {
+        if (!tripleClickTimer_.hasExpired (qApp->doubleClickInterval())
+            && event->buttons() == Qt::LeftButton)
+        {
+            tripleClickTimer_.invalidate();
+            QTextCursor txtCur = textCursor();
+            const QString txt = txtCur.block().text();
+            const int l = txt.length();
+            if (l > 10000) return;
+            txtCur.movePosition (QTextCursor::StartOfBlock);
+            int i = 0;
+            while (i < l && txt.at (i).isSpace())
+                ++i;
+            /* WARNING: QTextCursor::movePosition() can be a mess with RTL
+                        but QTextCursor::setPosition() works fine. */
+            if (i < l)
+            {
+                txtCur.setPosition (txtCur.position() + i);
+                int j = l;
+                while (j > i && txt.at (j -  1).isSpace())
+                    --j;
+                txtCur.setPosition (txtCur.position() + j - i, QTextCursor::KeepAnchor);
+            }
+            else
+                txtCur.setPosition (txtCur.position() + i, QTextCursor::KeepAnchor);
+            setTextCursor (txtCur);
+            return;
+        }
+        tripleClickTimer_.invalidate();
+    }
+
     /* get the global press position if it's inside a selection to know
        whether there will be a real mouse movement at mouseMoveEvent() */
     if (event->buttons() == Qt::LeftButton
@@ -1857,6 +2047,12 @@ void TextEdit::mouseReleaseEvent (QMouseEvent *event)
     pressPoint_ = QPoint();
 }
 /*************************/
+void TextEdit::mouseDoubleClickEvent (QMouseEvent *event)
+{
+    tripleClickTimer_.start();
+    QPlainTextEdit::mouseDoubleClickEvent (event);
+}
+/*************************/
 bool TextEdit::event (QEvent *event)
 {
     if (highlighter_
