@@ -21,6 +21,9 @@
 #define VSCROLLBAR_H
 
 #include <QScrollBar>
+#if (QT_VERSION >= QT_VERSION_CHECK(5,14,0))
+#include <QWheelEvent>
+#endif
 
 namespace FeatherPad {
 
@@ -39,6 +42,19 @@ private:
     int defaultWheelSpeed;
 };
 
+#if (QT_VERSION >= QT_VERSION_CHECK(5,14,0))
+/* A (temporary) workaround for Qt's horizontal scrollbar bug. */
+class HScrollBar : public QScrollBar
+{
+    Q_OBJECT
+public:
+    HScrollBar (QWidget *parent = nullptr) : QScrollBar (parent) {};
+
+protected:
+    void wheelEvent (QWheelEvent *event);
+};
+#endif
+
 }
 
 #endif // VSCROLLBAR_H
